@@ -1,13 +1,16 @@
+#' @noRd
 msg_sfplus_required <- function(var, verb = "Omitting") {
   stop(verb, " '", var, "' is reserved for SimFin+ users.", call. = FALSE)
 }
 
 #' @importFrom checkmate assert_string
+#' @noRd
 check_api_key <- function(api_key) {
-  checkmate::assert_string(api_key, pattern = "^[a-zA-Z0-9]+(-[a-zA-Z0-9]+)*$")
+  checkmate::assert_string(api_key)#, pattern = "^[a-zA-Z0-9]+(-[a-zA-Z0-9]+)*$")
 }
 
 #' @importFrom checkmate assert_directory
+#' @noRd
 check_cache_dir <- function(cache_dir) {
   if (!is.null(cache_dir)) {
     checkmate::assert_directory(cache_dir, access = "rw")
@@ -15,11 +18,13 @@ check_cache_dir <- function(cache_dir) {
 }
 
 #' @importFrom checkmate assert_logical
+#' @noRd
 check_sfplus <- function(sfplus) {
   checkmate::assert_logical(sfplus, any.missing = FALSE, len = 1L)
 }
 
 #' @importFrom checkmate assert_character
+#' @noRd
 check_ticker <- function(ticker) {
   checkmate::assert_character(
     ticker,
@@ -30,9 +35,10 @@ check_ticker <- function(ticker) {
 }
 
 #' @importFrom checkmate assert_integerish
-check_simfin_id <- function(simfin_id) {
+#' @noRd
+check_id <- function(id) {
   checkmate::assert_integerish(
-    simfin_id,
+    id,
     lower = 1L,
     any.missing = FALSE,
     null.ok = TRUE
@@ -40,18 +46,21 @@ check_simfin_id <- function(simfin_id) {
 }
 
 #' @importFrom checkmate assert_choice
+#' @noRd
 check_statement <- function(statement, sfplus) {
-  checkmate::assert_choice(
+  checkmate::assert_subset(
     statement,
-    c("pl", "bs", "cf", "derived", "all"),
+    c("pl", "bs", "cf", "derived"),
+    empty.ok = FALSE,
     fmatch = TRUE
   )
-  if (statement == "all" & isFALSE(sfplus)) {
-    stop('statement = "all" is reserved for SimFin+ users.', call. = FALSE)
-  }
+  # if (statement == "all" & isFALSE(sfplus)) {
+  #   stop('statement = "all" is reserved for SimFin+ users.', call. = FALSE)
+  # }
 }
 
 #' @importFrom checkmate assert_choice
+#' @noRd
 check_period <- function(period, sfplus, called_from_get_shares = FALSE) {
   checkmate::assert_choice(
     period,
@@ -71,14 +80,16 @@ check_period <- function(period, sfplus, called_from_get_shares = FALSE) {
   }
 }
 
+#' @noRd
 check_period_get_shares <- function(...) {
   check_period(...)
 }
 
 
 #' @importFrom checkmate assert_integerish
+#' @noRd
 check_fyear <- function(fyear, sfplus) {
-  if (is.null(fyear) & isFALSE(sfplus)) {
+  if (is.null(fyear) && isFALSE(sfplus)) {
     msg_sfplus_required("fyear")
   }
   checkmate::assert_integerish(
@@ -88,6 +99,8 @@ check_fyear <- function(fyear, sfplus) {
     null.ok = TRUE
   )
 }
+
+#' @noRd
 check_fyear_get_shares <- function(..., type) {
   if (type %in% c("wa-basic", "wa-diluted")) {
     check_fyear(...)
@@ -95,8 +108,9 @@ check_fyear_get_shares <- function(..., type) {
 }
 
 #' @importFrom checkmate assert_date
+#' @noRd
 check_start <- function(start, sfplus) {
-  if (!is.null(start) & isFALSE(sfplus)) {
+  if (!is.null(start) && isFALSE(sfplus)) {
     msg_sfplus_required("start", "Specifying")
   }
   checkmate::assert_date(
@@ -108,8 +122,9 @@ check_start <- function(start, sfplus) {
 }
 
 #' @importFrom checkmate assert_date
+#' @noRd
 check_end <- function(end, sfplus) {
-  if (!is.null(end) & isFALSE(sfplus)) {
+  if (!is.null(end) && isFALSE(sfplus)) {
     msg_sfplus_required("end", "Specifying")
   }
   checkmate::assert_date(
@@ -121,15 +136,17 @@ check_end <- function(end, sfplus) {
 }
 
 #' @importFrom checkmate assert_logical
+#' @noRd
 check_ttm <- function(ttm) {
   checkmate::assert_logical(ttm, any.missing = FALSE, len = 1L)
 }
 
 #' @importFrom checkmate assert_logical
+#' @noRd
 check_shares <- function(shares, sfplus) {
   checkmate::assert_logical(shares, any.missing = FALSE, len = 1L)
 
-  if (isTRUE(shares) & isFALSE(sfplus)) {
+  if (isTRUE(shares) && isFALSE(sfplus)) {
     stop(
       "'shares = TRUE' is reserved to SimFin+ users. As a normal user, please ",
       "use 'sfa_get_shares()' with 'type = \"wa-basic\"' or 'type = ",
@@ -140,8 +157,9 @@ check_shares <- function(shares, sfplus) {
 }
 
 #' @importFrom checkmate assert_logical
+#' @noRd
 check_ratios <- function(ratios, sfplus) {
-  if (!is.null(ratios) & isFALSE(sfplus)) {
+  if (!is.null(ratios) && isFALSE(sfplus)) {
     msg_sfplus_required("ratios", "Specifying")
   }
   checkmate::assert_logical(
@@ -153,6 +171,7 @@ check_ratios <- function(ratios, sfplus) {
 }
 
 #' @importFrom checkmate assert_choice
+#' @noRd
 check_type <- function(type) {
   checkmate::assert_choice(
     type,
@@ -162,6 +181,7 @@ check_type <- function(type) {
 }
 
 #' @importFrom checkmate assert_choice
+#' @noRd
 check_ref_data <- function(ref_data) {
   checkmate::assert_choice(
     ref_data,
