@@ -12,22 +12,20 @@
 #'   from the 'SimFin' API calls.
 #' @param create [logical] Set `TRUE` if you want to create `path` automatically
 #'   if it does not yet exist.
+#' @return [character] The cache directory (invisibly).
 #' @export
 sfa_set_cache_dir <- function(path, create = FALSE) {
-  checkmate::assert_string(path)
-  checkmate::assert_logical(create, any.missing = FALSE, len = 1L)
+    checkmate::assert_string(path)
+    checkmate::assert_logical(create, any.missing = FALSE, len = 1L)
 
-  if (!dir.exists(path)) {
-    if (isFALSE(create)) {
-      stop(
-        "'", path,
-        "' does not exist. Use 'create = TRUE' to create it on the fly."
-      )
-    } else {
-      dir.create(path, recursive = TRUE)
+    if (!dir.exists(path)) {
+        if (isFALSE(create)) {
+            stop("'", path, "' does not exist. Use 'create = TRUE' to create it on the fly.")
+        } else {
+            dir.create(path, recursive = TRUE)
+        }
     }
-  }
 
-  options(sfa_cache_dir = path)
-  return(invisible(getOption("sfa_cache_dir")))
+    options(sfa_cache_dir = path)
+    return(invisible(getOption("sfa_cache_dir")))
 }
